import mysql.connector

def run_query(host, user, password, database, query):
    """
    return records from the database.
    """
    try:
        my_db = mysql.connector.connect(
        host=host,
        user=user,
        password=password,
        database=database
        )
        my_cursor = my_db.cursor()
        my_cursor.execute(query)
        my_result = my_cursor.fetchall()
        return my_result
    except Exception as Error:
        return Error



from time import time

def calculate_time(func):
    """
    Calculates Function Execution Run time in Minutes.
    """
    def wrapper(*args, **kwargs): 
        start = time() 
        result = func(*args, **kwargs) 
        end = time() 
        print('Function '+func.__name__+' executed in ' + str((end-start)/60)[:6] +'m')
        return result 
    return wrapper 


import requests

def telegram_notification(token, message, chat_id):
    """
    Sends Telegram Message
    """
    url = f'https://api.telegram.org/bot{token}/sendMessage'
    payload = {
        "text": message,
        "parse_mode": "html",
        "chat_id" : chat_id
    }
    headers = {
        "accept": "application/json",
        "content-type": "application/json"
    }
    response = requests.post(url, json=payload, headers=headers)
    return response